<table>
  <tr>
    <th>Subject</th>
    <th>Body</th>
    <th>Attachment</th>
    <th></th>
    <th></th>
    <th></th>
  </tr>
  <%= render @comment %>
</table>

<br />

<%= link_to 'Back', comments_path %>
