// FIXME: Tell people that this is a manifest file, real code should go into discrete files
// FIXME: Tell people how Sprockets and CoffeeScript works
//
<% require_asset "jquery#{ENV['JQUERY_VERSION']}" %>
<% require_asset "jquery_ujs" %>
<% require_asset "jquery.remotipart" %>
<% require_asset "comments" %>

