<h1>Listing comments</h1>

<table id='comments'>
  <tr>
    <th>Subject</th>
    <th>Body</th>
    <th>Attachment</td>
    <th>Other Attachment</td>
    <th></th>
    <th></th>
    <th></th>
  </tr>

  <%= render @comments %>
</table>

<br />

<%= render 'new_comment_links' %>
